Package: koRpus
Type: Package
Title: Text Analysis with Emphasis on POS Tagging, Readability, and
        Lexical Diversity
Description: A set of tools to analyze texts. Includes, amongst others, functions for automatic language detection, hyphenation, several indices of lexical diversity (e.g., type token ratio, HD-D/vocd-D, MTLD) and readability (e.g., Flesch, SMOG, LIX, Dale-Chall). Basic import functions for language corpora are also provided, to enable frequency analyses
                                        (supports Celex and Leipzig Corpora Collection file formats) and measures like tf-idf. Note: For full functionality a local installation of TreeTagger is recommended. It is also recommended to not load this package directly, but by loading one of the available language support packages from the 'l10n' repository
                                        <https://undocumeantit.github.io/repos/l10n/>. 'koRpus' also includes a plugin for the R GUI and IDE RKWard, providing graphical dialogs for its basic features. The respective R package 'rkward' cannot be installed directly from a repository, as it is a part of RKWard. To make full use of this feature, please install
                                        RKWard from <https://rkward.kde.org> (plugins are detected automatically). Due to some restrictions on CRAN, the full package sources are only available from the project homepage. To ask for help, report bugs, request features, or discuss the development of the package, please subscribe to the koRpus-dev mailing list
                                        (<https://korpusml.reaktanz.de>).
Depends: R (>= 3.0.0),sylly (>= 0.1-7)
Imports: data.table,methods,Matrix (>= 1.3-0)
Enhances: rkward
Suggests:
        testthat,tm,SnowballC,shiny,knitr,rmarkdown,koRpus.lang.de,koRpus.lang.en,koRpus.lang.es,koRpus.lang.fr,koRpus.lang.it,koRpus.lang.nl,koRpus.lang.pt,koRpus.lang.ru
VignetteBuilder: knitr
URL: https://reaktanz.de/?c=hacking&s=koRpus
BugReports: https://github.com/unDocUMeantIt/koRpus/issues
Additional_repositories: https://undocumeantit.github.io/repos/l10n
License: GPL (>= 3)
Encoding: UTF-8
LazyLoad: yes
Authors@R: c(person(given="Meik", family="Michalke", email="meik.michalke@hhu.de", role=c("aut", "cre")), person(given="Earl", family="Brown", email="ekbrown@ksu.edu", role=c("ctb")), person(given="Alberto", family="Mirisola", role=c("ctb")), person(given="Alexandre", family="Brulet", role=c("ctb")), person(given="Laura", family="Hauser", role=c("ctb")))
Version: 0.13-9
Date: 2026-02-02
RoxygenNote: 7.3.3
Collate: '01_class_01_kRp.text.R' '02_method_filterByClass.R'
        'koRpus-internal.R' '00_environment.R' '01_class_02_kRp.TTR.R'
        '01_class_03_kRp.corp.freq.R' '01_class_04_kRp.lang.R'
        '01_class_05_kRp.readability.R'
        '01_class_81_kRp.connection_union.R'
        '02_method_get_set_kRp.text.R'
        '01_class_90_deprecated_classes.R' '02_method_cTest.R'
        '02_method_clozeDelete.R' '02_method_correct.R'
        '02_method_docTermMatrix.R' '02_method_freq.analysis.R'
        '02_method_hyphen.R' '02_method_jumbleWords.R'
        '02_method_lex.div.R' '02_method_pasteText.R'
        '02_method_plot.kRp.text.R' '02_method_query.R'
        '02_method_read.corp.custom.R' '02_method_readTagged.R'
        '02_method_readability.R' '02_method_show.kRp.lang.R'
        '02_method_show.kRp.TTR.R' '02_method_show.kRp.corp.freq.R'
        '02_method_show.kRp.readability.R' '02_method_show.kRp.text.R'
        '02_method_split_by_doc_id.R' '02_method_summary.kRp.lang.R'
        '02_method_summary.kRp.TTR.R'
        '02_method_summary.kRp.readability.R'
        '02_method_summary.kRp.text.R' '02_method_textTransform.R'
        '02_method_tokenize.R' '02_method_treetag.R'
        '02_method_types_tokens.R' 'available.koRpus.lang.R'
        'get.kRp.env.R' 'guess.lang.R' 'install.koRpus.lang.R'
        'kRp.POS.tags.R' 'kRp.cluster.R'
        'koRpus-internal.freq.analysis.R' 'koRpus-internal.import.R'
        'koRpus-internal.lexdiv.formulae.R'
        'koRpus-internal.rdb.formulae.R'
        'koRpus-internal.rdb.params.grades.R'
        'koRpus-internal.read.corp.custom.R' 'koRpus-package.R'
        'lex.div.num.R' 'read.BAWL.R' 'read.corp.LCC.R'
        'read.corp.celex.R' 'readability.num.R' 'segment.optimizer.R'
        'set.kRp.env.R' 'set.lang.support.R' 'textFeatures.R'
        'wrapper_functions_lex.div.R' 'wrapper_functions_readability.R'
NeedsCompilation: no
Packaged: 2026-02-02 08:17:34 UTC; m
Author: Meik Michalke [aut, cre],
  Earl Brown [ctb],
  Alberto Mirisola [ctb],
  Alexandre Brulet [ctb],
  Laura Hauser [ctb]
Maintainer: Meik Michalke <meik.michalke@hhu.de>
Repository: CRAN
Date/Publication: 2026-02-03 10:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 23:34:37 UTC; unix
