# Generated by roxygen2: do not edit by hand

export("corpusCorpFreq<-")
export("corpusFreq<-")
export("corpusHyphen<-")
export("corpusLexDiv<-")
export("corpusReadability<-")
export("corpusStopwords<-")
export("diffText<-")
export("feature<-")
export("hasFeature<-")
export("taggedText<-")
export(ARI)
export(C.ld)
export(CTTR)
export(DRP)
export(ELF)
export(FOG)
export(FORCAST)
export(HDD)
export(K.ld)
export(LIX)
export(MATTR)
export(MSTTR)
export(MTLD)
export(R.ld)
export(RIX)
export(S.ld)
export(SMOG)
export(TRI)
export(TTR)
export(U.ld)
export(available.koRpus.lang)
export(bormuth)
export(cTest)
export(clozeDelete)
export(coleman)
export(coleman.liau)
export(corpusCorpFreq)
export(corpusFreq)
export(corpusHyphen)
export(corpusLexDiv)
export(corpusReadability)
export(corpusStopwords)
export(correct.tag)
export(dale.chall)
export(danielson.bryan)
export(dickes.steiwer)
export(diffText)
export(docTermMatrix)
export(doc_id)
export(farr.jenkins.paterson)
export(feature)
export(filterByClass)
export(fixObject)
export(flesch)
export(flesch.kincaid)
export(freq.analysis)
export(fucks)
export(get.kRp.env)
export(guess.lang)
export(gutierrez)
export(harris.jacobson)
export(hasFeature)
export(install.koRpus.lang)
export(is.kRp.text)
export(is.taggedText)
export(jumbleWords)
export(kRp.POS.tags)
export(kRp.cluster)
export(kRp.filter.wclass)
export(kRp.text.paste)
export(kRp.text.transform)
export(kRp_TTR)
export(kRp_analysis)
export(kRp_corp_freq)
export(kRp_lang)
export(kRp_readability)
export(kRp_tagged)
export(kRp_text)
export(kRp_txt_freq)
export(kRp_txt_trans)
export(lex.div)
export(lex.div.num)
export(linsear.write)
export(maas)
export(nWS)
export(originalText)
export(pasteText)
export(plot)
export(query)
export(read.BAWL)
export(read.corp.LCC)
export(read.corp.celex)
export(read.corp.custom)
export(read.tagged)
export(readTagged)
export(readability)
export(readability.num)
export(segment.optimizer)
export(set.kRp.env)
export(set.lang.support)
export(spache)
export(split_by_doc_id)
export(strain)
export(summary)
export(taggedText)
export(textFeatures)
export(textTransform)
export(tif_as_tokens_df)
export(tokenize)
export(tokens)
export(traenkle.bailer)
export(treetag)
export(tuldava)
export(types)
export(wheeler.smith)
exportClasses(kRp.TTR)
exportClasses(kRp.analysis)
exportClasses(kRp.corp.freq)
exportClasses(kRp.lang)
exportClasses(kRp.readability)
exportClasses(kRp.tagged)
exportClasses(kRp.text)
exportClasses(kRp.txt.freq)
exportClasses(kRp.txt.trans)
exportMethods("[")
exportMethods("[<-")
exportMethods("[[")
exportMethods("[[<-")
exportMethods("corpusCorpFreq<-")
exportMethods("corpusFreq<-")
exportMethods("corpusHyphen<-")
exportMethods("corpusLexDiv<-")
exportMethods("corpusReadability<-")
exportMethods("corpusStopwords<-")
exportMethods("describe<-")
exportMethods("diffText<-")
exportMethods("feature<-")
exportMethods("hasFeature<-")
exportMethods("language<-")
exportMethods("taggedText<-")
exportMethods(cTest)
exportMethods(clozeDelete)
exportMethods(corpusCorpFreq)
exportMethods(corpusFreq)
exportMethods(corpusHyphen)
exportMethods(corpusLexDiv)
exportMethods(corpusReadability)
exportMethods(corpusStopwords)
exportMethods(correct.tag)
exportMethods(describe)
exportMethods(diffText)
exportMethods(docTermMatrix)
exportMethods(doc_id)
exportMethods(feature)
exportMethods(filterByClass)
exportMethods(fixObject)
exportMethods(freq.analysis)
exportMethods(hasFeature)
exportMethods(hyphen)
exportMethods(hyphen_c)
exportMethods(hyphen_df)
exportMethods(jumbleWords)
exportMethods(language)
exportMethods(lex.div)
exportMethods(originalText)
exportMethods(pasteText)
exportMethods(plot)
exportMethods(query)
exportMethods(read.corp.custom)
exportMethods(readTagged)
exportMethods(readability)
exportMethods(show)
exportMethods(split_by_doc_id)
exportMethods(summary)
exportMethods(taggedText)
exportMethods(textTransform)
exportMethods(tif_as_tokens_df)
exportMethods(tokenize)
exportMethods(tokens)
exportMethods(treetag)
exportMethods(types)
import(graphics)
import(methods)
import(stats)
import(utils)
importFrom(Matrix,Matrix)
importFrom(data.table,":=")
importFrom(data.table,data.table)
importFrom(sylly,"describe<-")
importFrom(sylly,"hyphenText<-")
importFrom(sylly,"language<-")
importFrom(sylly,describe)
importFrom(sylly,get.sylly.env)
importFrom(sylly,hyphen)
importFrom(sylly,hyphenText)
importFrom(sylly,hyphen_c)
importFrom(sylly,hyphen_df)
importFrom(sylly,language)
importFrom(sylly,set.hyph.support)
importFrom(sylly,set.sylly.env)
importFrom(utils,available.packages)
importFrom(utils,install.packages)
importFrom(utils,packageDescription)
